@@ -6,10 +6,10 @@ https://www.aug.ipp.mpg.de/aug/manuals/aug_sfutils
 
 """
 __author__  = 'Giovanni Tardini (Tel. 1898)'
-__version__ = '0.5.0'
-__date__    = '02.11.2021'
+__version__ = '0.5.1'
+__date__    = '03.11.2021'
 
-import sys, logging
+import os, sys, logging
 
 fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s', '%H:%M:%S')
 hnd = logging.StreamHandler()
@@ -41,6 +41,8 @@ from .sfread import *
 from .sf2equ import *
 from .libddc import ddcshotnr, previousshot
 from .mapeq import *
-from .getlastshot import *
+from .getlastshot import getlastshot
+sf_home = os.path.abspath(__file__)
+logger.info('AUG-SF home %s', sf_home)
 
 import encodings.utf_8
