@@ -1,4 +1,4 @@
-import os, sys, datetime, logging
+import sys, logging
 
 from aug_sfutils import libddc
 try:
