@@ -12,7 +12,9 @@ logger = logging.getLogger('aug_sfutils.mapeq')
 
 
 def get_nearest_index(tim_eq, tarr):
-    """Find nearest time index for a given time"""
+    """Find nearest time index for a given time.
+    For internal use only.
+    """
 
     tim_eq = np.atleast_1d(np.array(tim_eq, dtype=np.float32))
     if len(tim_eq) == 1:
