@@ -1,3 +1,8 @@
+"""Important definitions of object and data types, units, 
+calibration types, timebase types.
+Creating dict's for consistent type conversion.
+"""
+
 import numpy as np
 import ctypes as ct
 
