@@ -169,6 +169,9 @@ class SFH_READ:
 
 
     def update_set(self):
+        """
+        Metadata of an UPDATE_SET object
+        """
 
         self.items =  unpack('>H' , self.val[ 2: 4])[0]
         self.input_vals = unpack('>i' , self.val[ 4: 6])[0]
@@ -176,6 +179,9 @@ class SFH_READ:
 
 
     def loctimer(self):
+        """
+        Metadata of an LOCTIMER object
+        """
 
         self.data_format, self.resolution = unpack('>2H', self.val[: 4])
         self.size = unpack('>I', self.val[20: 24])[0]
@@ -203,5 +209,8 @@ class SFH_READ:
 
 
     def addrlen(self):
+        """
+        Value of ADDRLEN object
+        """
 
         self.addrlen = unpack('>H' , self.val[ : 2])[0]
