@@ -193,6 +193,9 @@ class SFREAD:
         """
 
         obj = str_byt.to_str(obj)
+        if obj not in self.sfh.keys():
+            logger.error('Sig/TB %s:%s not found for #%d', self.diag, obj, self.shot)
+            return None
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
         if otyp == 8:
@@ -211,6 +214,9 @@ class SFREAD:
         """
 
         obj = str_byt.to_str(obj)
+        if obj not in self.sfh.keys():
+            logger.error('Sig/AB %s:%s not found for #%d', self.diag, obj, self.shot)
+            return None
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
         if otyp == 13:
